@@ -25,7 +25,7 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2010 Igalia, S.L."
 __license__   = "LGPL"
 
-import orca.default as default
+import orca.scripts.default as default
 import orca.debug as debug
 import gtk.gdk as gdk
 
